CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_constants.h File Reference

CCL

Macros
ccl_constants.h File Reference
`#include "gsl/gsl_const_mksa.h"`

Go to the source code of this file.

## Macros
#define | A_SPLINE_TYPE gsl_interp_akima
#define | K_SPLINE_TYPE gsl_interp_akima
#define | M_SPLINE_TYPE gsl_interp_akima
#define | D_SPLINE_TYPE gsl_interp_akima
#define | PNL_SPLINE_TYPE gsl_interp2d_bicubic
#define | PLIN_SPLINE_TYPE gsl_interp2d_bicubic
#define | K_PIVOT 0.05
#define | RHO_CRITICAL 2.7744948E11
#define | CLIGHT_HMPC 2997.92458
#define | GNEWT 6.67428e-11
#define | SOLAR_MASS 1.9885e30
#define | MPC_TO_METER 3.08567758149e22
#define | PC_TO_METER 3.08567758149e16
#define | KBOLTZ GSL_CONST_MKSA_BOLTZMANN
#define | STBOLTZ GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT
#define | HPLANCK GSL_CONST_MKSA_PLANCKS_CONSTANT_H
#define | CLIGHT GSL_CONST_MKSA_SPEED_OF_LIGHT
#define | EV_IN_J GSL_CONST_MKSA_ELECTRON_VOLT
#define | TNCDM 0.71611
#define | EPSREL_DIST 1E-6
#define | EPSREL_GROWTH 1E-6
#define | EPSREL_DNDZ 1E-6
#define | EPS_SCALEFAC_GROWTH 1E-6

## Macro Definition Documentation

## ◆ A_SPLINE_TYPE

#define A_SPLINE_TYPE gsl_interp_akima

## ◆ CLIGHT

#define CLIGHT GSL_CONST_MKSA_SPEED_OF_LIGHT

The speed of light in m/s

## ◆ CLIGHT_HMPC

#define CLIGHT_HMPC 2997.92458

Lightspeed / H0 in units of Mpc/h

## ◆ D_SPLINE_TYPE

#define D_SPLINE_TYPE gsl_interp_akima

## ◆ EPS_SCALEFAC_GROWTH

#define EPS_SCALEFAC_GROWTH 1E-6

Absolute precision in growth calculations

## ◆ EPSREL_DIST

#define EPSREL_DIST 1E-6

Relative precision in distance calculations

## ◆ EPSREL_DNDZ

#define EPSREL_DNDZ 1E-6

Relative precision in dNdz calculations

## ◆ EPSREL_GROWTH

#define EPSREL_GROWTH 1E-6

Relative precision in growth calculations

## ◆ EV_IN_J

#define EV_IN_J GSL_CONST_MKSA_ELECTRON_VOLT

Electron volt to Joules convestion

## ◆ GNEWT

#define GNEWT 6.67428e-11

Newton's gravitational constant in units of m^3/Kg/s^2 (from PDG 2013)

## ◆ HPLANCK

#define HPLANCK GSL_CONST_MKSA_PLANCKS_CONSTANT_H

Planck's constant in units kg m^2 / s

## ◆ K_PIVOT

#define K_PIVOT 0.05

k pivot. These are in units of Mpc (no factor of h)

## ◆ K_SPLINE_TYPE

#define K_SPLINE_TYPE gsl_interp_akima

## ◆ KBOLTZ

#define KBOLTZ GSL_CONST_MKSA_BOLTZMANN

Boltzmann constant in units of J/K

## ◆ M_SPLINE_TYPE

#define M_SPLINE_TYPE gsl_interp_akima

## ◆ MPC_TO_METER

#define MPC_TO_METER 3.08567758149e22

Mpc to meters (from PDG 2013)

## ◆ PC_TO_METER

#define PC_TO_METER 3.08567758149e16

pc to meters (from PDG 2013)

## ◆ PLIN_SPLINE_TYPE

#define PLIN_SPLINE_TYPE gsl_interp2d_bicubic

## ◆ PNL_SPLINE_TYPE

#define PNL_SPLINE_TYPE gsl_interp2d_bicubic

## ◆ RHO_CRITICAL

#define RHO_CRITICAL 2.7744948E11

Rho critical in units of M_sun/h / (Mpc/h)^3

## ◆ SOLAR_MASS

#define SOLAR_MASS 1.9885e30

Solar mass in units ofkg (from PDG 2013)

## ◆ STBOLTZ

#define STBOLTZ GSL_CONST_MKSA_STEFAN_BOLTZMANN_CONSTANT

Stefan-Boltzmann constant in units of kg/s^3 / K^4

## ◆ TNCDM

#define TNCDM 0.71611

T_ncdm, as taken from CLASS, explanatory.ini